/*
 * Copyright 2004 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.myfaces.component;

import javax.faces.context.FacesContext;

/**
 * ExecuteOnCapable interface for extended components
 * This is a modification to the findComponent principle found
 * in the JSF spec. With executeOn, we want to make sure that a component
 * can itself prepare its childComponent to be in the correct state
 * before executing a method on it.
 *
 * With findComponent - you get a component, but this component might
 * not be prepared to  have the context information. This
 * is important for e.g. DataTables. They'll need to prepare the component
 * with the current row-state to make sure that the method is executed
 * correctly.
 *
 *
 * @author Martin Marinschek (latest modification by $Author: grantsmith $)
 */

public interface ExecuteOnCapable
{
    /**Call this method instead of find on a component,
     * and you will be able to execute some instructions on it
     * by providing an ExecuteOnCallback handler.
     *
     * @param facesContext
     * @param clientId
     * @param executeOnCallback
     * @return Object the return value of your ExecuteOnCallback-handler.
     */
    Object executeOn(FacesContext facesContext,
                     String clientId, ExecuteOnCallback executeOnCallback);
}
