/*
 * Copyright 2006 The Apache Software Foundation.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.myfaces.renderkit.html.util;

import java.util.HashSet;
import java.util.Set;

/**
 * Convenient class to store whether a dummyForm needs to be rendered and its params.
 * This class will be stored in the request when a dummyForm is needed to be rendered in the page.
 * AddResources will add it from a method called from the ExtensionsFilter.
 * <p>
 * All this replaces the old system based in a DummyFormResponseWriter
 *
 * @author Bruno Aranda (latest modification by $Author: baranda $)
 * @version $Revision: 373272 $ $Date: 2006-01-29 02:01:37 +0000 (Sun, 29 Jan 2006) $
 */
public class DummyFormRequestInfo
{

   private Set _dummyFormParams = null;

   public String getDummyFormName()
   {
       return DummyFormUtils.DUMMY_FORM_NAME;
   }

   public void addDummyFormParameter(String paramName)
   {
       if (_dummyFormParams == null)
       {
           _dummyFormParams = new HashSet();
       }
       _dummyFormParams.add(paramName);
   }

   public Set getDummyFormParams()
   {
       return _dummyFormParams;
   }
}
